package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````L"4```````!``````````$"Q````
M`````````$``.``-`$``'``;``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````)`9````````D!D`````````
M$`````````$````%`````"``````````(``````````@````````13T`````
M``!%/0`````````0`````````0````0`````8`````````!@`````````&``
M``````!02````````%!(`````````!`````````!````!@```."K````````
MX+L```````#@NP```````$`$````````F`0`````````$`````````(````&
M````\*L```````#PNP```````/"[``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M```@H0```````""A````````(*$```````#L`````````.P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````X*L```````#@NP```````."[````
M````(`0````````@!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50`M`I1AR"%MEC:J/I@/07+=$(8"W00````0````
M`0```$=.50```````P````(``````````````!$````_````!`````@````@
M'!``!4`$AB@"``2`A@"$@@D`($D@!`BX@A%!N@`""@`````_````0@```$4`
M``!&````30```$X```!0`````````%0```!5````5@```%@```!:````7```
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP$+ZUX?"Y3\LNN.2?/NA;&!K"4/69J_,9L6YG$`X\HL<Q(D%D$)%U>R)
M!W#3,V+;[16,)<P,.I<+I]VC:WZIG)O19<YMX*<""FL:GE`*BA!7H^#[20``
M`````````````````````````````.0````2````````````````````````
M`)8````2`````````````````````````!@"```2````````````````````
M`````%T!```2`````````````````````````/L!```2````````````````
M`````````,(!```2`````````````````````````/H````2````````````
M``````````````$````@`````````````````````````(L"```2````````
M`````````````````,$"```2`````````````````````````)4!```2````
M`````````````````````.P!```2`````````````````````````'0!```2
M`````````````````````````"L!```2`````````````````````````!L!
M```2`````````````````````````-X!```2````````````````````````
M`!("```2``````````````````````````T!```2````````````````````
M`````*$!```2`````````````````````````&T#```2````````````````
M`````````!`````@`````````````````````````'L!```2````````````
M`````````````.D````2`````````````````````````!X"```2````````
M`````````````````"P````@`````````````````````````&,"```2````
M`````````````````````&H"```2`````````````````````````$8````2
M`````````````````````````&,````6`````````````````````````$T!
M```2`````````````````````````'8````2````````````````````````
M`-,````2`````````````````````````(<````2````````````````````
M`````%H"```2`````````````````````````-<!```2````````````````
M``````````L"```2`````````````````````````+<````2````````````
M`````````````)`"```2`````````````````````````*@!```2````````
M`````````````````)H!```2`````````````````````````#\!```2````
M`````````````````````'H"```2`````````````````````````"4"```2
M`````````````````````````.X````2`````````````````````````)D"
M```2`````````````````````````-`!```2````````````````````````
M`.4!```2`````````````````````````&("```2````````````````````
M`````/0!```2`````````````````````````*(````2````````````````
M`````````&@!```2`````````````````````````'("```2````````````
M``````````````("```2`````````````````````````#X"```2````````
M`````````````````*H"```2`````````````````````````"P"```2````
M`````````````````````#0!```2`````````````````````````%0````2
M`````````````````````````+`!```2`````````````````````````%,"
M```2`````````````````````````#0"```2````````````````````````
M`+$"```2`````````````````````````'8#```2``\`8$$````````4`0``
M`````,L#```2``\`8#<```````#@!P```````+T!```2``\`H",````````&
M`@```````.T"```2``\`P"T````````%``````````L#```2``\`0#\`````
M```@`@```````/$#```2``\`T"T````````"`@```````+$#```0`!D`(,``
M`````````````````/X"```2``\`X"\````````B`````````"$#```2``\`
ML#4```````!T`````````((#```1`!$``&`````````$`````````)X#```2
M``\`0%D```````"?`0```````*D#```2``\`T"P````````E`````````,8#
M```0`!D`>,```````````````````-\#```2``\`4#8````````+`0``````
M`)$#```0`!@``,```````````````````$4#```2``\`$#`````````Q`0``
M`````+<"```1`!D`(,`````````(`````````$P"```1`!D`0,`````````(
M`````````+@"```A`!D`(,`````````(`````````-@#```0`!@`(,``````
M`````````````/X#```1`!@`&,`````````(`````````)<#```2``\`L"4`
M```````B`````````+T#```2``\`\%@```````!%`````````),#```@`!@`
M`,```````````````````+D"```A`!D`(,`````````(`````````%L#```2
M``\`,#8````````=`````````(8!```B`````````````````````````"\#
M```2``\``"T```````"Y`````````%$#```2``\`X%H```````!+`@``````
M`,8````1`!D`4,`````````!``````````@$```2``\`4#$```````!<!```
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E
M<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?8WAA7V9I;F%L
M:7IE`')E860`<W1R8VAR`&=E='!I9`!M96UM;W9E`%]?;&EB8U]S=&%R=%]M
M86EN`%]?9G!R:6YT9E]C:&L`<W1R8VUP`&]P96XV-`!U;FQI;FL`<W1R=&]K
M`'-T<FYC;7``9V5T=6ED`&UE;6-H<@!C;&]S961I<@!S=')S='(`<FUD:7(`
M8VQO<V4`<W1R;&5N`'-T<F1U<`!R96%L;&]C`')E861D:7(V-`!?7W-P<FEN
M=&9?8VAK`'-T9&5R<@!M96UC<'D`<W1R<F-H<@!L<W1A=#8T`&]P96YD:7(`
M;'-E96LV-`!?7V5R<FYO7VQO8V%T:6]N`&5X:70`<F5A9&QI;FL`7U]S=&%C
M:U]C:&M?9F%I;`!A8V-E<W,`;6MD:7(`7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`<&%R7V-U<G)E;G1?
M97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E
M;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H
M85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU
M<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I
M;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E
M9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L
M`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT
M`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR
M+C4````!``$``@`!``(``P`!``$``@`$``(``@`"``$``0`"``(``0`"``(`
M`0`!``(``@`!``4``@`!``$``0`!``$``0`"``(``@`!``(``@`"``$``@`"
M``$`!@`"``(`!0`"``$``0`"``(``P`"``(``0`!``<`"``"``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`"``(``@`!``$``0`!``$``@`!
M``(``0`!``$``0`!``<`XP(``!``````````E)&6!@``"``5!```$````+21
ME@8```<`(`0``!`````4:6D-```&`"L$```0````LY&6!@``!0`U!```$```
M`'(9:0D```0`0`0``!````!T&6D)```#`$P$```0````=1II"0```@!8!```
M`````."[````````"`````````"0)@```````.B[````````"`````````!0
M)@````````C`````````"``````````(P````````!C`````````"```````
M``#88@```````+B_````````!@````<``````````````,"_````````!@``
M``@``````````````,B_````````!@```!4``````````````-"_````````
M!@```!D``````````````-B_````````!@```%D``````````````."_````
M````$@```!T``````````````.B_````````!@```!X``````````````/"_
M````````!@```!\``````````````/B_````````!@```#L`````````````
M`"#`````````!0```$\``````````````$#`````````!0```%``````````
M`````%#`````````!0```%P```````````````B^````````!P````$`````
M`````````!"^````````!P````(``````````````!B^````````!P````,`
M`````````````""^````````!P````0``````````````"B^````````!P``
M``4``````````````#"^````````!P````8``````````````#B^````````
M!P````D``````````````$"^````````!P````H``````````````$B^````
M````!P````L``````````````%"^````````!P````P``````````````%B^
M````````!P````T``````````````&"^````````!P````X`````````````
M`&B^````````!P````\``````````````'"^````````!P```!``````````
M`````'B^````````!P```!$``````````````("^````````!P```!(`````
M`````````(B^````````!P```!,``````````````)"^````````!P```!0`
M`````````````)B^````````!P```!8``````````````*"^````````!P``
M`!<``````````````*B^````````!P```!@``````````````+"^````````
M!P```!H``````````````+B^````````!P```!L``````````````,"^````
M````!P```!P``````````````,B^````````!P```"```````````````-"^
M````````!P```"$``````````````-B^````````!P```"(`````````````
M`."^````````!P```",``````````````.B^````````!P```"0`````````
M`````/"^````````!P```"4``````````````/B^````````!P```"8`````
M``````````"_````````!P```"<```````````````B_````````!P```"@`
M`````````````!"_````````!P```"D``````````````!B_````````!P``
M`"H``````````````""_````````!P```"L``````````````"B_````````
M!P```"P``````````````#"_````````!P```"T``````````````#B_````
M````!P```"X``````````````$"_````````!P```"\``````````````$B_
M````````!P```#```````````````%"_````````!P```#$`````````````
M`%B_````````!P```#(``````````````&"_````````!P```#,`````````
M`````&B_````````!P```#0``````````````'"_````````!P```#4`````
M`````````'B_````````!P```#8``````````````("_````````!P```#<`
M`````````````(B_````````!P```#@``````````````)"_````````!P``
M`#D``````````````)B_````````!P```#H``````````````*"_````````
M!P```#P``````````````*B_````````!P```#T``````````````+"_````
M````!P```#X`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%M9\``$B%P'0"_]!(@\0(PP```````````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)4*<``!FD```````````55-(@^PXB7PD'$B-?"0<
M2(ET)!!(C70D$$B)5"0(2(U4)`AD2(L$)2@```!(B40D*#'`Z'C___](BS79
MFP``2(L]"IP``$B)\NA".0``@#U;G`````^$%0$``$B+!=Z;``!D2(L`@(@J
M!````XM$)!R->`2-6`-(8_](P><#Z+W^__](BWPD$$2+1"0<2(G!2(D%,9P`
M`$B+!TB)`4B-!7\]``!(B4$(2(L%R9L``$B)01!(C05L/0``2(E!&$&#^`$/
MCB4!``!(@\<(08/``[H$````#Q\`2(L'2&/R@\(!2(/'"$B)!/%$.<)UZDAC
MTDB+/=B;``!%,<!(C37>!P``2,<$T0````")VNBO^___B<.%P`^$A0```$B+
M/:Z;``!(C6PD).AT_?__,<!(B>Y(C3W+.P``Z,,!``!(A<!T<4B+/8>;``#H
M0OO__^BM_/__2(M$)"AD2"L$)2@````/A9H```!(@\0XB=A;7</H._S__TB)
M!52;``!(B<=(A<!T<^B7_/__2(L%L)H``&1(BQ#&@M<)````Z<+^__](BSTI
MFP``Z)3[__^)P^EH____2(L]!IL``$B%_W0*Z/P;``#I>?___TB-/>@Z``!(
MB>[H*`$``$B)!>&:``!(B<=(A<`/A%?____KTKH$````Z??^__^_`0```.CO
M^O__Z-K\__]F+@\?A```````,>U)B=%>2(GB2(/D\%!413'`,<E(C3W5_?__
M_Q4GF@``]&8N#Q^$```````/'T``2(T].9H``$B-!3*:``!(.?AT%4B+!<Z9
M``!(A<!T"?_@#Q^``````,,/'X``````2(T]"9H``$B--0*:``!(*?Y(B?!(
MP>X_2,'X`T@!QDC1_G042(L%E9D``$B%P'0(_^!F#Q]$``###Q^``````/,/
M'OJ`/?:9````=2M52(,]<ID```!(B>5T#$B+/9:9``#H&?W__^AD____Q@7.
MF0```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=!5D%505154TB#
M[`A(A?\/A+$```!,BS5BF0``387V#X2A````#[8'28G_28GUA,!T!#P]=5A%
M,>1)BQY(A=MT,TUCY$R)]0\?@`````!,B>),B?Y(B=_HPOG__X7`=0="@#PC
M/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M00^V1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````Q
MP$B)YN@:^___A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(```!(
MB=_H7_O__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U"4B!
MQ*````!;P^B-^O__9F8N#Q^$``````!FD$%505154TB![*@```!D2(L$)2@`
M``!(B80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4C
M`0``2('$J````%M=05Q!7<-F#Q]$``#H,_G__TB)Q4B%P'3(2(GOZ`/[__](
MA<`/A+(```"`>!,N3(U@$W4008!\)`$`=-T/'X0``````(!X$RX/A*8```!(
MB=_HSOC__TR)YTF)Q>C#^/__08U\!0)(8__H%OC__TV)X4F)V+X!````28G%
M2(G',<!(Q\+_____2(T-*3<``.@P^O__3(GO2(GFZ)7X__],B>^#^/]T$(M$
M)!@E`/```#T`0```=%WH^/?__TR)[^A0^/__2(GOZ%CZ__](A<`/A57___\/
M'X``````2(GOZ-#Y__](B=_HV/?__^GP_O__#Q\`08!\)`$N#X5.____08!\
M)`(`#X0-____Z3W___\/'P#HF_[__^NAZ!3Y__\/'T``056Z_P\``$%454B)
M]5-(B?M(C3V"-@``2('L&!```&1(BP0E*````$B)A"0($```,<!)B>1,B>;H
M8_C__X7`?A*)P8/H`4ACT(`\%`!U287`=3U(BP46E@``2(GJ2(G>9$B+..A'
M]___2(N$)`@0``!D2"L$)2@```!U3TB!Q!@0``!;74%<05W#9@\?1```B<%F
M#Q]$``!,8^F^+P```$R)YTR)ZNA5]O__2(7`=*-(BP6YE0``3(GI3(GB2(G>
M9$B+..C']___ZY[H0/C__T%7059!54%454B)]5-(B?M(@^P89$B+!"4H````
M2(E$)`@QP#'`@#X]#Y3`2`'%2(GOZ/GV__](C70D!$B)WTF)Q#'`Z!?\__](
MA<`/A`8!``!(B<=)B<7HT_;__TPYX`^#T@```$QC="0$2<'F`P^V`X3`#X2>
M`0``/#T/A)8!``!(B=@/'P`/ME`!2(/``832=`6`^CUU[T@IV$B83(LM.Y4`
M`$J-?"`"Z.'U__]-`?5)B44`2(7`=%9(BP4>E0``2(U+`4J+%#`/M@.(`H3`
M="(\/74-ZQP/'X``````A,!T$0^V`4B#P@%(@\$!B`(\/77KQ@(],<!F#Q]$
M```/MDP%`(A,`@%(@\`!A,EU[TB+1"0(9$@K!"4H````#X4'`0``2(/$&%M=
M05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``
M3(L]@90``$F#/P`/A+8```!,B?A%,>V02(/`"$2)ZD&#Q0%(@S@`=>^-<@-(
M8_9(P>8#BP6'E```A<!U6\<%>90```$```!(B??HZ?3__TB%P`^$8?___TUC
M]4R)_DB)QTG!Y@-,B?+H&_;__TB)!124``!(B<%!C44!1(EL)`1(F$C'!,$`
M````Z8C^__]F#Q^$``````!,B?_H^/;__TB)!>&3``!(B<%(A<`/A`;___]-
M8_5)P>8#Z[L/'T``,<#I?_[__[X0````13'MZ5_____H#_;__V9F+@\?A```
M````#Q]``%-(BQU8DP``2(T-070``$B--8,S``!(BQ5+DP``9$B+.^B:]O__
M9$B+.T4QR5M,C07K-```2(T5A!(``$R)P4B--6\S``#IY?3__P\?1```2(L%
M"9,``$B+%0J3``!(C0WK<P``2(TU+3,``&1(BSCI2_;__V9F+@\?A```````
M55-(@>PH(```9$B+!"4H````2(F$)!@@```QP$B)XTB-K"00$```Z`3T__^Z
M`1```$B)W[X!````08G`3(T-TC(``#'`2(T-_C(``.B_]?__N@`0``!(B>Y(
MB=_HK_3__X7`>%"->`%(B<-(8__H7?/__TB%P'0]2&/;2(GN2(G'2(G:Z-?U
M___&!!@`2(G!2(N$)!@@``!D2"L$)2@```!U#4B!Q"@@``!(B<A;7</HR_3_
M_S')Z]</'X``````Z3O___]F9BX/'X0``````$%7059!54%428G\2(T]=C(`
M`%532(GS2('LN!```&1(BP0E*````$B)A"2H$```,<!(C70D#.B5^/__OB\`
M``!,B>=(B<7H%?3__TB%P'1`,<!,B>9(C3TU,@``Z`_\__],B>!(BY0DJ!``
M`&1(*Q0E*`````^%@@$``$B!Q+@0``!;74%<05U!7D%?PP\?`$B)WTR-+00R
M``!,C37J,@``Z.KS__],B>Y(B<?H'_3__TB)PTB%P'27@#L`#X3D````9@\?
M1```2(7M=!-(B=Y(B>_HZ//__X7`#X2G````2(G?Z+CR__](C50#_TF)QT@Y
MTW(7ZR5F#Q^$``````#&`@!(@^H!2#G3=`6`.B]T[TB)W^B'\O__28G'3(GG
MZ'SR__])C40'`4@]_P\```^'&____TR-O"2@````3(GQ28G8,<!(@^P(N@`0
M``"^`0```$R)_T%43(T-03$``.C<\___2(UT)"!,B?_H/_+__UI9A<!U$(M$
M)"@E`/```#T`@```=$E,B>XQ_^@_\___2(G#2(7`#X2S_O__@#L`#X4B____
M2(7M=`:`?0`N=!=!OP$```!(C1W(,```Z5G___\/'T0``(!]`0!TN>OAO@$`
M``!,B?_H<_/__X7`=:9,B?Y(C3VF,```Z(#Z__],B?_HF/+__^EG_O__Z*[R
M__]F9BX/'X0```````\?`%.^+P```$B)^^CB\?__2(U0`4B%P$@/1=I(B=];
MZ5[R__]F9BX/'X0```````\?`%532('L&!```&1(BP0E*````$B)A"0($```
M,<!(A?\/A,L```"`/P!(B?L/A+\```#H*O'__TB-4`%(@?H`$```#X?A````
M2(GE2(GO@_H(<@Z)T4B)WL'I`_-(I4B)\S')]L($=`F+"XD/N00```#VP@)T
M#D0/MP0+9D2)!`](@\$"@^(!=`</MA0+B!0/2(U$!?](.<5R$^L6#Q]$``#&
M``!(@^@!2#GH=`6`."]T[[XO````2(GOZ`+Q__](A<!T+4@YQ7)82(GOZ(#Q
M__](BY0D"!```&1(*Q0E*````'5)2('$&!```%M=PP\?`$B+A"0($```9$@K
M!"4H````=2E(@<08$```2(T]-2\``%M=Z3CQ__\/'X0``````,8``.NC#Q\`
M,<#KI.@_\?__9F8N#Q^$```````/'T``05=!5D%505152(TM$B\``%-(@^P8
M9$B+!"4H````2(E$)`@QP$B-7"0$9@\?1```,<!(B=Y(B>_H$_7__TB%P'0V
M2&-4)`1(BP6"C@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```2(TMK"X``)`QP$B)WDB)[^C#]/__2(7`=#9(8U0D!$B+!3*.
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(
MC2UD+@``D#'`2(G>2(GOZ'/T__](A<!T-DAC5"0$2(L%XHT``$B-!-!(BU`(
M2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-+1TN``"0,<!(
MB=Y(B>_H(_3__TB%P'0V2&-4)`1(BP62C0``2(T$T$B+4`A(B1!(A=)TTF:0
M2(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TMU"T``)`QP$B)WDB)[^C3\___
M2(7`=#9(8U0D!$B+!4*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)
M$$B%TG7PZ[YF#Q]$``!,C264+0``D#'`2(G>3(GGZ(/S__](A<!T-DAC5"0$
M2(L%\HP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/
M'T0``$R-)?DL``"0,<!(B=Y,B>?H,_/__TB%P'0V2&-4)`1(BP6BC```2(T$
MT$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TU`"T`
M`)`QP$B)WDR)]^CC\O__2(7`=#9(8U0D!$B+!5*,``!(C0302(M0"$B)$$B%
MTG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C2VZ+```D#'`2(G>3(GO
MZ)/R__](A<!T-DAC5"0$2(L%`HP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(
M@\`(2(D02(72=?#KOF8/'T0``$R-/70L``"0,<!(B=Y,B?_H0_+__TB%P'0V
M2&-4)`1(BP6RBP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```3(T]PBL``)`QP$B)WDR)_^CS\?__2(7`=#9(8U0D!$B+!6*+
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(
MB=Y(C3W;*P``Z*GQ__](A<!T#4B)QDR)[S'`Z#?U__\QP$B)WDB-/<DK``#H
MAO'__TB%P'012(G&2(T]QRL``#'`Z!#U__](B=Y(C3W!*P``,<#H7_'__TB)
MQDB%P'0Y3(GG,<#H[?3__TB+1"0(9$@K!"4H````=41(@\082(GO2(TUJRL`
M`#'`6UU!7$%=05Y!7^F^]/__,<!(B=Y(C3U]*P``Z`WQ__](A<!TNTB)QDR)
M]S'`Z)OT___KK.C4[/__#Q]``$B#[!AD2(L$)2@```!(B40D"(L%2(H``(/X
M_W0;2(M4)`AD2"L4)2@```!U0DB#Q!C#9@\?1```2(UT)`1(C3V[*@``,<#H
MI?#__TB)PC'`2(72=!(/M@(\,`^5PH3`#Y7`#[;`(=")!?.)``#KKNA<[/__
M9F8N#Q^$``````"02(/L".B'[/__B<?H`.O__TB%P'0#2(L`2(/$",,/'P!!
M54%43(TEPRH``%5(B?U,B>=32(/L&&1(BP0E*````$B)1"0(,<!(C70D!.@?
M\/__2(7`=`B`.`!(B<-U,DB+1"0(9$@K!"4H````#X6T````2(GN2(/$&$R)
MYS'`6UU!7$%=Z8?S__\/'X``````2(GN2(G'Z"7K__](A<!T($B+1"0(9$@K
M!"4H````=79(@\086UU!7$%=PP\?1```2(GOZ'CJ__](B=])B<7H;>K__TF-
M?`4"Z,/I__](@^P(28GHO@$```!32,?"_____TB)QTF)Q4R-#4`I``!(C0TF
M*@``,<#HU.O__UA:2(M$)`AD2"L$)2@```!U"$R)[NE/____Z"7K__\/'T0`
M`$%72(T-S"D``$B-%98I``!!5F9(#V[!2(T-:RD``$F)_D%52(T]SB@``$%4
M55-(@>R(@0``9$B+!"4H````2(F$)'B!``!(C06I*```2(U<)!Q(QT0D,```
M``!(QX0DB`````````!(B=Y(QT0D4`````!F2`]NR$B-!5LI``!F#VS!9D@/
M;M!(C053*0``#RE$)"!F2`]NP69(#V[82(T-02D``&8/;,)(C04[*0``#Q%$
M)&AF2`]NPF9(#V[@,<!F#VS##Q%$)'AF2`]NP68/;,0/*40D0.AC[O__2(7`
M=`R`.`!(B<4/A5($``#H;>K__XG'Z.;H__](A<`/A,T#``!,BRA-A>T/A,$#
M``!,B>_H^>C__TB-?``!Z$_H__]%#[9%`$F)QTF)Q$6$P'0^2(TMO"@```\?
MA```````10^VP$R)_TB)Z;X!````2,?"_____S'`28/%`4F#QP+H2^K__T4/
MMD4`183`==%,C6PD8$B-/14H``#K$`\?`$F+?0A)@\4(2(7_=#-(B=XQP.BI
M[?__2(G%2(7`=.&`.`!TW$B)Q^AD[O__A<!TT$B)[^A(Z?__2(G%2(7`=3A,
MC6PD($F+;0!(A>UT*H!]```/A.@"``!(B>_H,.[__X7`#X7X````28MM"$F#
MQ0A(A>UUV0\?`$B)[^@0Z/__3(GG28G%Z`7H__]!C80%!`0``$QC^$R)_^A2
MY___051)B>B^`0```$F)Q4B-!=`G``!,C0W7)@``2,?"_____U!(C0VQ)P``
M3(GO,<#H7NG__TR)[[[``0``Z,'I__]?05B#^/]U$NB$Z/__1(L(08/Y$0^%
MH0(``$B-M"20````3(GOZ,?H__^)Q87`='%)BPY(BSU'A@``38GH,<!(C14+
M*```O@$```#H<>;__T4QY$B+A"1X@0``9$@K!"4H````#X42!0``2('$B($`
M`$R)X%M=05Q!74%>05_#9I!(B>])@\4(Z!3H__](B<5(A<`/A,W^___I^_[_
M_P\?`(N$)*@````E`/```#T`0```#X5X____1(ND)*P```#H/.C__T$YQ`^%
M8O___XN$)*@````E_P$``#W``0``#X5+____3(G_Z"3F__](B=Y(C3US)@``
M28G$,<#HX.O__TB%P`^$-P(``$F+/DB)QNC\\O__28G'2(7`#X0@`@``3(G_
MZ(CF__](B<*#^`-^0$B82(TU;B8``$B)5"0(28U\!_SHB.?__X7`=21(BU0D
M"(/Z!`^$?0,``(U"^TB808`\!R\/A&T#``!F#Q]$``"+!=J$``"#^/\/A"$#
M``"%P`^$T0$``$B--<XE``!(C3U:)0``,<#HY.[__TB-'3TF``!,C34D)@``
MZ,'E__]32,?"_____TV)Z%!,C0WN)```O@$```!,B>=(C0WO)0``,<#H>.?_
M_UA:ZT0/'T``Z*OF__^#.!%U2.B!Y?__@\4!2(/L"$V)Z%-,C0VO)```3(GQ
MO@$```!52,?"_____TR)YU`QP.@TY___2(/$(+[``0``3(GGZ)/G__^#^/]T
MKDR)[^AFY?__3(GF2(T]5"0``#'`Z#7N__],B>?H/?K__^GZ_?__#Q^$````
M```Q[>DQ_?__9@\?A```````2(UL)$#K#68/'X0``````$B#Q0A(BWT`2(7_
M#X2'````,<!(B=[H1>K__TB%P'3@@#@`=-M(B<?H\^7__TF)Q4B%P'3+Z?7[
M__])BPY(BSV\@P``38GH,<!(C15`)0``O@$```#HYN/__^EP_?__D$B)Q^BH
M^?__2(N$)'B!``!D2"L$)2@````/A7P"``!(@<2(@0``2(GO6UU!7$%=05Y!
M7^F(Y?__OPT```!,C2U*)```Z.?C__]!N%,```!)B<=)B<3IE_O__V8/'T0`
M`$V+/NG8_?__QP7^@@```````&8/'T0``#'V3(G_,<#HO.3__XG#A<`/A!G^
M__^Z`@```$C'QN[___^)Q^BOY?__3(VT)'`!``"Z!@```(G?3(GVZ%CC__^`
MO"1P`0```'4.@+PD<0$``$,/A&(!```QTC'VB=_H=>7__S'`Z&X;``!(B<7K
M%&8/'X0``````$R)]DB)[^BE&P``N@"```!,B?:)W^@&X___B<*%P'_@B=],
MC;0D(`$``$B-G"1H`0``Z(GB__](B>Y,B?=(C2V`(P``Z`<=``!(C80D0`$`
M`$B)1"0(28G'#Q^``````$4/M@9,B?](B>F^`0```$C'PO____\QP$F#QP))
M@\8!Z/OD__],.?MUUDB-!7\C``#&A"1H`0```%#_="002(T-/",``$V)Z$R)
MYS'`O@$```!,C0TG(@``2,?"_____^B[Y/__65[IEOW__P\?0``QP$B)WDB-
M/4,B``#H+^C__TB%P`^$CO[__P^V`(3`#Y7"/#`/E<`/ML`AT(D%?H$``.FH
M_/__38MV"$V%]@^$C/S__TR)]^C$XO__2(/X`P^&>OS__TF-?`;\2(TUJB(`
M`.C)X___A<!-#T3^Z5[\__^`O"1R`0``00^%D/[__X"\)',!``!##X6"_O__
M@+PD=`$``$@/A73^__^`O"1U`0``10^%9O[__[H"````2,?&QO___XG?Z-/C
M__^Z*0```$R)]HG?Z(3A__](C05M(@``4$%6Z?/^___H0./__T%42(T]2B$`
M`%532(/L$$B+'8J```!D2(L$)2@```!(B40D"#'`3(UD)`1,B>9D2(LK#[:%
ML````(B%L0```#'`Z!KG__](A<!T"8`X,0^$9`$``#'`Z+7Q__]D2(LK2(GO
MN0,```"Z`0```$B-->PA``#H..'__TB)Q4B%P'0H2(M`$&1(BSM(C172(0``
M2(LPZ$GA__](BT402(LP]D8.0`^%2`$``&1(BSNY`P```+H!````2(TUJ2$`
M`.CNX/__2(G%2(7`="U,B>9(C3U-(```,<#HA>;__TB)PDB%P`^$Z0```$B+
M11!D2(L[2(LPZ.G@__]D2(L[N@$```!(C35A(0``Z/3?__]D2(L[2(T59B$`
M`$B)QNC!X/__9$B+`TR)YDB-/>L?``#&@+$`````,<#H)>;__TB)!=Y_``!(
MB<-(A<!T/K[``0``2(G?Z.GB__^-4`&#^@%V"8/X$0^%E@```$B+1"0(9$@K
M!"4H````#X6?````2(/$$%M=05S##Q\`2(L]F7\``.B,]O__2(D%A7\``$B)
MPTB%P'6G2(T]?B$``#'`Z-_A__\/'X``````@'@!``^$G?[__^F-_O__9@\?
MA```````2(L%47\``$B+,$B+11!(BSCH2NC__^D,____#Q]$``!D2(L[Z#?A
M___IJO[__XG!2(L%(7\``$B)VDB-/3\A``!(BS`QP.AUX?__Z"#A__]!5%5(
MB?U32(/L$&1(BP0E*````$B)1"0(,<#HD.[__[XO````2(G'2(G#Z$#@__](
MA<!(C5`!2`]%VDB)W^B]X/__2(7M28G$BP5A?@``#Y7#@_C_=&F%P`^5P"'#
MA-MU'DB+1"0(9$@K!"4H````#X69````2(/$$%M=05S#D(!]``!TW+H$````
M2(TU<!\``$R)Y^C&WO__A<!UQ$B+1"0(9$@K!"4H````=6%(@\002(GO6UU!
M7.GBY?__9I`QP$B-="0$2(T]@1X``.AMY/__2(7`="@/MA"$T@^5P(#Z,`^5
MPB'0(<,/ML")!;U]``#I9O___P\?A```````QP6F?0```````.E3____Z`S@
M__]F+@\?A```````9I!!5TB)_DR-1SA!5D%505154TB![)@"``!D2(L$)2@`
M``!(B80DB`(``#'`2(GB3(V,)(````!(B=</'X``````08L`38L02(/'$$F#
MP`@/R(G`3(G12(E'\$R)T$C!Z2!(P>@H2<'J."4`_P``3`G028G*2,'A"$G!
MXAB!X0``_P!%B=),"=!("<A(B4?X3#G/=:UF#V]$)!!F#V]<)"!(C40D:$B!
MPF@"``!F#V]4)#!F#V\MIUT```\?@`````#S#V\(9@]OXF8/;U#82(/`$&8/
M[T"(9@_ORF8/[\%F#V_(9@]ST!]F#W/Q`68/Z\%F#]O%#RE`"&8/;\-F#V_<
M2#G0=;M,BPY,BUX02(M^($B+7AA,B<A,B<I(BVX(2(M,)`A(P>H;2,'@!4@)
MT`,$)$B-C`N9>8):C90XF7F"6DR)V$@QV$@AZ$@QV(T\`DB)ZDB)Z$C!Z`)(
MP>(>28GZ2`G"3(G82<'J&T&)T$PQP$PAR$PQV$@!R$B)^4C!X05,"=%,BU0D
M$$2-)`A,B<A,B<E(P>D"2,'@'D^-E!.9>8):38GE2`G(2<'M&T@QPHG!2"'Z
M3#'"3`'238GB2<'B!4T)ZDR+;"0800'22(GZ2,'O`DC!XAY%B=)/C80HF7F"
M6D@)^DV)U4@QT(G73"'@2<'M&T@QR$P!P$V)T$G!X`5-">A,BVPD($$!P$R)
MX$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*
M3(G!2,'A!4P)Z4R+;"0H`=%,B=))P>H"2,'B'HG)2HV\+YEY@EI,"=))B<U(
M,=!)P>T;08G23"'`3#'@2`'X2(G/2,'G!4P)[TR+;"0P`<=,B<!)P>@"2,'@
M'HG_3XVD+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)
M[$R+;"0X00'42(G*2,'I`DC!XAY%B>1/C90JF7F"6D@)RDV)Y4@QT$G![1N)
MT4@A^$PQP$P!T$V)XDG!X@5-">I,BVPD0$$!PDB)^$C![P)(P>`>18G23XV$
M*)EY@EI("?A-B=5(,<))P>T;B<=,(>)(,<I,`<)-B=!)P>`%30GH3(ML)$A!
M`=!,B>))P>P"2,'B'D6)P$J-C"F9>8):3`GB38G%2#'02<'M&T&)U$PAT$@Q
M^$@!R$R)P4C!X05,">E,BVPD4`'!3(G02<'J`DC!X!Z)R4J-O"^9>8):3`G0
M28G-2#'"2<'M&T&)PDPAPDPQXD@!^DB)STC!YP5,">],BVPD6`'73(G"2<'H
M`DC!XAZ)_T^-I"R9>8):3`G"28G]2#'02<'M&T&)T$@AR$PQT$P!X$F)_$G!
MY`5-">Q,BVPD8$$!Q$B)R$C!X!Y(P>D"18GD3XV4*IEY@EI("<A-B>5(,<))
MP>T;B<%((?I,,<),`=)-B>))P>(%30GJ3(ML)&A!`=)(B?I(P>\"2,'B'D6)
MTD^-A"B9>8):2`GZ38G52#'02<'M&XG73"'@2#'(3`'`38G02<'@!4T)Z$R+
M;"1P00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,
M(=)(,?I(`<I,B<%(P>$%3`GI3(ML)'@!T4R)TDC!XAY)P>H"B<E*C;POF7F"
M6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(NL)(`````!
MQTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),
M`>))B?Q)P>0%30GL1HTL(DB)RDC!Z0),BZ0DB````$C!XAY("<I/C90BF7F"
M6DV)[$@QT$G![!N)T4@A^$PQP$P!T$V)ZDG!X@5-">),BZ0DD````$$!PDB)
M^$C!X!Y(P>\"18G23XV$()EY@EI("?A-B=1(,<))P>P;B<=,(>I(,<I,`<)-
MB=!)P>`%30G@18G`3`'"38GH2<'M`DG!X!Y!B=1-">A,BZPDF````$PQP$PA
MT$J-C"F9>8):38GE2#'X2<'M&T@!R$R)X4C!X05,">F)R4@!R$R)T4G!Z@)(
MP>$>08G%3`G138G"18G`23'*1#'23(N4)*````!*C;P7H>O9;DV)ZD@!UTR)
MZDG!ZAM(P>(%3`G2B=)(`==,B>)(P>(>2<'L`D&)^DP#A"2H````3`GB28G,
MB<E(`XPDL````$DQU$0QX$V-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!
MQ$R)Z$G![0)(P>`>18G@3`GH28G5B=)(`Y0DN````$DQQ40Q[TR-K#FAZ]EN
M3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!)
M,<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B
M'D6)XDP)PDF)R$@#A"3`````B<E),=!(`XPDR````$4QZ$Z-K`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0D
MT````$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!
MZ@)(P>$>1(GG3`G128G"B<!(`X0DV````$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ
M2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!(`XPD
MX````$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$B)^$C![P)(
MP>`>18G@2`GX2(G7B=)(`Y0DZ````$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O
M&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D\````$DQ
MRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>
M18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$C!X`5)P>@;2`.,)/@`
M``!,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0D``$``$@QQT0Q
MYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG
M3`G128G"B<!(`X0D"`$``$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,
M"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!%,>!.C:0`H>O9;DR)
MT$V)T$G!Z!M(P>`%3`G`2`.,)!`!``")P$D!Q$B)^$C![P)(P>`>18G@2`GX
M2(G7B=)(`Y0D&`$``$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)
MR4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D(`$``$DQRD4QXDZ-I!*A
MZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(
MB<E),=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(P>`>
M2,'O`D6)Z$@#C"0H`0``2`GX2(G7B=)(`Y0D,`$``$@QQT0QYTV)Q$B-C#FA
MZ]EN3(G'2<'L&TC!YP5,">=-B=1)P>H"2<'D'HG_30G428G"2`'YB<!-,>*)
MST@#A"0X`0``13'J28G]3HV4$J'KV6Y(B?I)P>T;2,'B!4P)ZD$!TDR)PDG!
MZ`)(P>(>18G23`G"38G@18GD23'028G608G51#'!38G02(V,"*'KV6Y,B=!)
MP>@;2,'@!4P)P$2-!`%(B?E(P>\"N-R\&X](P>$>2`GY20G.B<]((?I-(=9)
M"=9(BY0D0`$``$@!PDP!XDV)Q$P!\DV)QDG!Y`5)P>X;30GT00'43(G22<'J
M`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0D2`$``$D!QDT!]4V)
MYDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)
M"<Y-(>9,(<),"?),B[0D4`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW
M`==,B>))P>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)%@!``!)
M`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G2
M3`GI08G-20G.22'^3"'J3`GR3(NT)&`!``!)`<9-`?!-B=9,`<)-B=!)P>`%
M2<'N&TT)\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,
MB[0D:`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J
M`DC!X1Y%B>1,"=%!B<I)"<Y-(<9,(=),"?),B[0D<`$``$D!QDT!]4V)YDP!
MZDV)Y4G![AM)P>4%30GU00'53(G"2,'B'DG!Z`)%B>U,"<)("=%)B=9!B=!-
M(=9,(>%,"?%,B[0D>`$``$D!QDP!]TV)[D@!^4R)[TG![AM(P><%3`GW28G6
M`<],B>%)P>P"2,'A'HG_3`GA08G,20G.32'N3"'B3`GR3(NT)(`!``!)`<9-
M`?))B?Y,`=))B?I)P>X;2<'B!4T)\D$!TDR)ZDG![0)(P>(>18G23`GJ2`G1
M28G608G52"'Y32'F3`GQ3(NT)(@!``!)`<9-`?!-B=9,`<%-B=!)P>X;2<'@
M!4T)\$F)UD$!R$B)^4C![P)(P>$>18G`2`GYB<])"<Y-(=9((?I,"?),B[0D
MD`$``$D!QDT!]$V)QDP!XDV)Q$G![AM)P>0%30GT00'43(G22<'J`DC!XAY%
MB>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0DF`$``$D!QDT!]4V)YDP!Z4V)
MY4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,
M(<),"?),B[0DH`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW`==,B>))
MP>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)*@!``!)`<9-`?))
MB?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-
M20G.22'^3"'J3`GR3(NT)+`!``!)`<9-`?!-B=9,`<)-B=!)P>X;2<'@!4T)
M\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0DN`$`
M`$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%
MB>1,"=%)"<Y!B<I-(<9,(=),"?),B[0DP`$``$D!QDT!]4V)YDP!ZDV)Y4G!
M[AM)P>4%30GU00'53(G"2<'H`DC!XAY%B>U,"<)("=%)B=!!B==-(=!,(>%,
M"<%,BX0DR`$``$D!P$P!QTV)Z$@!^4R)[TG!Z!M(P><%3`G'1(T$.4R)YTG!
M[`)(B=%(P><>3`GG08G\2`GY3"'I3"'B2`G*2(N,)-`!``!(`<%,`=%-B<)(
M`X0DV`$``$@!RDR)P4G!ZAM(P>$%3`G1B<E(`<I,B>E)P>T"2,'A'D&)TDP)
MZ4@)STF)S4&)SDPAQTTAY4D)_4J-/#A,B=!,B[PD^`$``$P![TV)U4C!X`5)
MP>T;3`GHB<!(`<=,B<!)P>@"2,'@'D&)_4D)P+C6P6+*3#'!,=%(BY0DX`$`
M`$@!PDP!XDV)[$@!RDR)Z4G![!M(P>$%3`GA38G4B<E)P>0>2`'*2<'J`DD!
MQTT)XDV)Q(G118G`33'41#'G3(ND).@!``!)`<1-`?1)B<Y,`>=)B<Q)P>X;
M2<'D!4T)]$V)[DG![0))P>8>18GD30GU3(NT)/`!``!,`>=!B?Q)`<9-`?!-
MB=9-,>Y$,?)-B>9)`=!,B>))P>X;2,'B!4P)\HG220'02(G*2,'I`DC!XAY%
MB<9("<I$B=%-B>I),=),`?E,B[PD``(``$0QUTV)\D@!STR)\4C!X05)P>H;
M20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\
M)!`"``!%,>A-B=5)`<A,B=%)P>T;20''2,'A!4P)Z8G)20'(3(GQ2<'N`DC!
MX1Y%B<5,"?%,B[0D"`(``$D!QDP!\DV)YDDQSD0Q]TV)[D@!UTR)ZDG![AM(
MP>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)TD2)XDF)S(G)3`'Z33'43(N\
M)"`"``!%,>!-B?1)`=!,B?))P>P;20''2,'B!4P)XHG220'03(GJ2<'M`DC!
MXAY%B<1,">I,BZPD&`(``$D!Q4P!Z4V)U4DQU40Q[TV)Y4@!STR)X4G![1M(
MP>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\
M)#`"``!%,=!-B>I)`<A,B>E)P>H;2,'A!4P)T8G)20'(3(GA2,'A'DG![`)%
MB<))`<=,">%,BZ0D*`(``$D!Q$P!XDV)]$DQS$0QYTV)U$@!UTR)TDG![!M(
MP>(%3`GBB=)(`==,B>I)P>T"2,'B'D&)_$D)U42)\DF)SHG)33'N3`'Z3(N\
M)$`"``!%,?!-B>9)`=!,B>))P>X;2,'B!4P)\HG220'03(G22<'J`DC!XAY%
MB<9,"=),BY0D.`(``$D!PDP!T4V)ZDDQTD0QUTV)\D@!STR)\4C!X05)P>H;
M20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\
M)&`"``!%,>A-B=5)`<A,B=%)P>T;2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%
MB<5,"?%,B[0D2`(``$D!QDP!\DV)YD6)Y$DQSD0Q]TV)[D@!UTR)ZDG![AM(
MP>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)TDB+E"10`@``2`'"20'42(G*
MB<E,,=))`<=$,<)-B?!)`=1,B?))P>@;2,'B!4P)PHG220'43(GJ2<'M`DC!
MXAY%B>!,">I,BZPD6`(``$D!Q4P!Z4V)U4DQU40Q[TV)Q4@!STR)P4G![1M(
MP>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\
M)'`"``!%,>)-B>Q,`=%-B>I)P>P;2<'B!4T)XDV)Q$6)TDG!Y!Y,`=%)P>@"
M20''30G@3(ND)&@"``!!B<I)`<1(`X0D>`(``$P!XDV)]$P!R$TQQ$0QYTV)
MU$@!UTR)TDG![!M(P>(%3`GB38GL2<'M`DG!Y!Z)TDT)Y46)]$V)QD@!UTTQ
M[HGZ30'\18G`1#'Q28G63`'`38GH3`'A28G42<'N&TG!Y`5-"?1$`>%-B=1)
MP>H"2<'D'HG)30GB33'01#''28G(2`'X2(G/2,'G!4G!Z!L!Z4$!VDP)QT0#
M;B!(B4X(`?A,B5882(D&2(G02,'J`DC!X!Y,B6X@2`G01`'82(E&$$B+A"2(
M`@``9$@K!"4H````=1)(@<28`@``6UU!7$%=05Y!7\/HELG__V8/'T0``$B#
M[`B_@````.C2Q___9@]O!>I'``!(QT`P``````\1`&8/;P7G1P``QT!X````
M``\10!!F#V\%Y$<```\10"!(@\0(PV9F+@\?A```````05=(8\)!5DF)QD%5
M051)B?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(
M`=!(B4<P2&-'>(7`#X7M````08/^/P^.*P$``$&#[D!%B?=!P>\&18UO`4G!
MY09)`=T/'T0``/,/;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/
M;UOP#Q%=,.BAZ/__3#GK=<Q!P><&12G^26/&2(/X"')<28M5`$B-30A(@^'X
M28E4)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#^`AR&$B#X/@QTDF+=!4`
M2(DT$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>05_#9I"H!'5T2(7`=.%!
M#[95`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``0;]`````2(U\!0!(B=Y!
M*<=%.?=%#T_^36/O3(GJZ,7(__]!BT0D>$0!^$&)1"1X@_A`=9),B>=%*?Y,
M`>OHQ>?__^G+_O__28G=Z2/___]!BU4`08E4)#A!BU0%_(E4!?SI6____Y!!
M5DR-=CA!54%454B)_5-,BVXH2(GS3(MF,$R)Z$C!Z`.#X#^-2`%(F,9$!CB`
M2&/!3`'P@_DX#XZ#`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S2(G?Z$/G
M__]F#^_`#Q%#.$G'1C``````00\11A!!#Q%&($R)XD$/ML5,B>],B>Y(P>H8
M2,'@"$R)X4C![Q!)B=!,B>I(P>X8#[;60`^V_T`/MO9(P>D02`G03(GB#[;)
M2,'@"$@)^`^V_D$/MM!(P>`(2`GP00^V]$C!X`A("?!(P>`(2`GX2(G?2,'@
M"$@)R$C!X`A("=!(B4-PZ*KF__](BP-(B=](P>@8B$4`2(L#2,'H$(A%`4B+
M`XAE`DB+`XA%`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(B&4&2(M#"(A%
M!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,0B&4*2(M#$(A%"TB+0QA(P>@8
MB$4,2(M#&$C!Z!"(10U(BT,8B&4.2(M#&(A%#TB+0R!(P>@8B$402(M#($C!
MZ!"(11%(BT,@B&422(M#((A%$UM=05Q!74%>Z<K$__]F+@\?A```````NC@`
M```Q_RG*@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A^$@IR`'"@^+X
M@_H(#X)^_O__@^+X,<")QH/`"$B)/#$YT'+SZ6?^___VP@1U(X72#X1:_O__
MQ@``]L("#X1._O__,<EFB4P0_NE"_O__#Q\`QP``````QT00_`````#I+/[_
M_P\?1```2(L-T6(``.EDP___2(/L"$B#Q`C#````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4V`"UE`"TM```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)$-!0TA%7VUA<FME<BP@)&-A8VAE7VYA;65?<VEZ92D[
M"D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F
M<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]M87)K97(@/2`B
M7#!#04-(12(["B1C86-H95]N86UE7W-I>F4@/2`T,#L*?0IS=6(@9FEN9%]P
M87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@
M/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@
M/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1P;W,@*ST@)&D[
M"G)E='5R;B`D<&]S.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N
M("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-
M;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F
M:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B([
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*
M+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M
M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M
M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D
M8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B
M3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I
M<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@
M,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O
M?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK
M*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B![
M"FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D
M=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D
M=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI
M<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I
M;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF
M;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D
M(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*=6YL97-S("@D8G5F(&5Q(")0
M2UPP,#-<,#`T(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@
M(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(
M+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD
M968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@
M>PIM>2`D<&%R7V-L96%N(#T@(CTQ(CL*;7D@)'!A<W-?<&%R7V-L96%N(#T@
M=6,@(E]?<&%S<U]P87)?8VQE86Y?7R(["B1L;V%D97(@/7X@<WLH/SP])'MP
M87-S7W!A<E]C;&5A;GTI*"`K*7T*>R1P87)?8VQE86X@+B`H(B`B('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'!A<E]C;&5A;BDI*7UE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T
M;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X[
M"F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T
M(ET["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C
M86-H95]N86UE7W-I>F4["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*;W!E;B!M>2`D=&@L("(\.G)A=R(L("1O=70["B1C='@M/F%D
M9&9I;&4H)'1H*3L*8VQO<V4@)'1H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE
M>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE
M7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`D
M8V%C:&5?;6%R:V5R.PIM>2`D;V9F<V5T(#T@)&9H+3YT96QL("L@;&5N9W1H
M*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*0HF
M)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@
M;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q
M<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X
M=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*
M;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T
M7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]
M("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@
M*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]
M"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@D
M8V%C:&5?;6%R:V5R*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE
M;F=T:"@D8V%C:&5?;6%R:V5R*3L*:68@*"1B=68@97$@)&-A8VAE7VUA<FME
M<BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*"1C86-H95]M87)K97(I"BT@)&-A8VAE7VYA;65?<VEZ92P@
M,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@
M<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E
M("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y
M<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M
M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC
M:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M
M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D[
M"GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)0
M05)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.
M5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I
M+F,`````````_____P````#_____``````$C16<`````B:O-[P````#^W+J8
M`````'94,A``````\.'2PP````````````````$;`SOL````'`````!___\X
M`0``<(+__V`!``"`@O__]`4``)"$__\(`0``@(7__W@!``!0AO__Q`$``."&
M___H`0``4(C__R0"```@B?__8`(``&"+__^L`@``L(O__\@"``#@B___W`(`
M`*",__\(`P``L(S__QP#``#`CO__?`,``/".__^8`P``,)#__]`#``"0E/__
M'`0``!"5__\X!```,)7__U`$``!`EO__K`0``"">__]\!0``0*#__[`%``!@
MH?__(`8``-"W__]P!@``(+C__X@&``#`N?__U`8``!"\__\8!P```````!0`
M`````````7I2``%X$`$;#`<(D`$'$!0````<````@(/__R(`````````````
M`!0``````````7I2``%X$`$;#`<(D`$``"0````<````P'W__W`#````#A!&
M#AA*#PMW"(``/QH[*C,D(@`````4````1`````B!__\(``````````````!(
M````7`````"$___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#
M!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`(````*@```"$A/__@P``
M``!!#A"#`DH.L`$"<0H.$$$."$$+.````,P```#PA/__;`$```!"#A"-`D(.
M&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X80@X00@X(1PL`.`````@!```D
MAO__T`````!"#A"-`D<.&(P#00X@A@1$#BB#!5$.P"`"9`H.*$$.($$.&$(.
M$$(."$<+2````$0!``"XAO__,0(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&1`XX@P='#E`#%0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"Q@```"0`0``
MK(C__TL`````00X0@P)M#@@````0````K`$``."(__\E`````````"@```#`
M`0``_(C__[D`````00X0A@)!#AB#`T<.P$`"H0H.&$0.$$$."$$+$````.P!
M``"0B?__!0````````!<``````(``(R)__\"`@```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%2PXPA@9!#CB#!TH.\"$"9`H..$$.,$$.*$(.($(.&$(.$$(."$0+
M`KD.^"%/#H`B6@[X(4$.\"$````8````8`(``#R+__\B`````$$.$(,"7`X(
M````-````'P"``!0B___,0$```!!#A"&`D$.&(,#1PZP(`+A"@X800X000X(
M1`M:"@X82`X000X(30M(````M`(``%B,__]<!````$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9(#CB#!T0.4`,"!`H..$T.,$$.*$(.($(.&$(.$$(."$4+
M&``````#``!LD/__=`````!$#B!M"@X(1PL``!0````<`P``T)#__QT`````
M1`X06`X(`%@````T`P``V)#__PL!````0@X0C0)"#AB,`T@.((8$1PXH@P5$
M#D`"0@H.*$8.($$.&$(.$$(."$P+9`H.*$$.($$.&$(.$$(."$8+80Y(20Y0
M8PY(00Y`````S````)`#``",D?__X`<```!"#A"/`E`.&(X#40X@C01)#BB,
M!4$.,(8&00XX@P='#L"#`@/K`0[(@P)A#M"#`E\.R(,"0@[`@P(";@H..$0.
M,$$.*$(.($(.&$(.$$(."$,+`S`!#LB#`DL.T(,"7@[(@P)!#L"#`EP.R(,"
M1`[0@P)0#MB#`DL.X(,"2P[`@P("Y@H..$0.,$$.*$(.($(.&$(.$$(."$4+
M`U(!#LB#`D0.T(,":`[(@P)!#L"#`@+="@[(@P)"#M"#`D4+`#````!@!```
MG)C__R`"````0@X0C`)(#AB&`T$.((,$1`XP`W$!"@X@00X800X00@X(1`M`
M````E`0``(B:__\4`0```$(.$(P"00X8A@-$#B"#!$0.,`)O"@X@00X800X0
M0@X(0@MR"@X@1`X800X00@X(1PL``"@```#8!```A'S__P8"````00X0A@)!
M#AB#`T0.4`-E`0H.&$,.$$$."$$+3`````0%```XF___:A8```!"#A"/`DD.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`T(6"@XX00XP00XH0@X@0@X8
M0@X00@X(00L````4````5`4``%BQ__]%`````$0.$`)`#@A(````;`4``)"Q
M__^?`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+E"@XX
M00XP00XH0@X@0@X80@X00@X(0PL`0````+@%``#DLO__2P(```!"#A".`D8.
M&(T#0@X@C`1!#BB&!40.,(,&`YL!"@XH00X@0@X80@X00@X(3PL````````0
M````_`4``/"T__\,````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"0)@```````%`F
M`````````0````````#3`@````````$`````````XP(````````,````````
M```@````````#0`````````\70```````!D`````````X+L````````;````
M``````@`````````&@````````#HNP```````!P`````````"`````````#U
M_O]O`````*`#````````!0````````!@#0````````8`````````D`0`````
M```*`````````&0$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````0!0```````!0`````````
M!P`````````7`````````(`4````````!P``````````$P````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````(`2````````____;P`````!````````
M`/#__V\`````Q!$```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#PNP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#88@```````$=#
M0SH@*$1E8FEA;B`Q,BXR+C`M-2D@,3(N,BXP```N<VAS=')T86(`+FEN=&5R
M<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E
M+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N
M<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````&`,````````8`P```````!P````````````````````!````````
M````````````$P````<````"`````````#@#````````.`,````````@````
M````````````````"````````````````````"8````'`````@````````!8
M`P```````%@#````````)`````````````````````0`````````````````
M```Y````!P````(`````````?`,```````!\`P```````"``````````````
M```````$````````````````````1P```/;__V\"`````````*`#````````
MH`,```````#P``````````8`````````"````````````````````%$````+
M`````@````````"0!````````)`$````````T`@````````'`````0````@`
M````````&`````````!9`````P````(`````````8`T```````!@#0``````
M`&0$```````````````````!````````````````````80```/___V\"````
M`````,01````````Q!$```````"\``````````8``````````@`````````"
M`````````&X```#^__]O`@````````"`$@```````(`2````````@```````
M```'`````0````@```````````````````!]````!`````(``````````!,`
M````````$P```````(`!````````!@`````````(`````````!@`````````
MAP````0```!"`````````(`4````````@!0````````0!0````````8````7
M````"``````````8`````````)$````!````!@``````````(``````````@
M````````%P````````````````````0```````````````````",`````0``
M``8`````````("`````````@(````````'`#```````````````````0````
M`````!``````````EP````$````&`````````)`C````````D",````````(
M````````````````````"``````````(`````````*`````!````!@``````
M``"@(P```````*`C````````G#D``````````````````!``````````````
M``````"F`````0````8`````````/%T````````\70````````D`````````
M```````````$````````````````````K`````$````"``````````!@````
M`````&`````````@00``````````````````$````````````````````+0`
M```!`````@`````````@H0```````""A````````[```````````````````
M``0```````````````````#"`````0````(`````````$*(````````0H@``
M`````$`&```````````````````(````````````````````S`````X````#
M`````````."[````````X*L````````(````````````````````"```````
M```(`````````-@````/`````P````````#HNP```````.BK````````"```
M``````````````````@`````````"`````````#D````!@````,`````````
M\+L```````#PJP`````````"````````!P`````````(`````````!``````
M````FP````$````#`````````/"]````````\*T````````0`@``````````
M````````"``````````(`````````.T````!`````P``````````P```````
M``"P````````(`````````````````````@```````````````````#S````
M"`````,`````````(,`````````@L````````%@````````````````````@
M````````````````````^`````$````P````````````````````(+``````
M```>`````````````````````0`````````!``````````$````#````````
M`````````````````#ZP`````````0$```````````````````$`````````
(````````````
